=============================
``psyclone.core.access_info``
=============================

.. automodule:: psyclone.core.access_info

   .. contents::
      :local:

.. currentmodule:: psyclone.core.access_info


Classes
=======

- :py:class:`AccessInfo`:
  This class stores information about a single access

- :py:class:`SingleVariableAccessInfo`:
  This class stores a list with all accesses to one variable.

- :py:class:`VariablesAccessInfo`:
  This class stores all `SingleVariableAccessInfo` instances for all


.. autoclass:: AccessInfo
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: AccessInfo
      :parts: 1

.. autoclass:: SingleVariableAccessInfo
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: SingleVariableAccessInfo
      :parts: 1

.. autoclass:: VariablesAccessInfo
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: VariablesAccessInfo
      :parts: 1
